# Conf.py
#
# Copyright (C) 2008 - Teemu Kallio <teemu.kallio@cs.helsinki.fi>
#				2009-2010 - Floreal Morandat <morandat AT lirmm DOT fr>
#					2012-2013 - Mehmet Giritli <mehmet@giritli.eu>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>

from gi.repository import Gst, Gio

EQUALIZER_DCONF_SCHEMA_ID = 'org.gnome.rhythmbox.plugins.equalizer'
EQUALIZER_BANDS_DCONF_SCHEMA_ID = EQUALIZER_DCONF_SCHEMA_ID + '.bands'
EQUALIZER_PRESET = 'preset'
EQUALIZER_CUSTOM_PRESETS = 'custom-presets'
EQUALIZER_DCONF_PATH = '/org/gnome/rhythmbox/plugins/equalizer/'
EQUALIZER_AUTO_SELECT = 'auto-select'

class Config:
	def __init__(self):
		self.dconf_keys = [	'band0',
					'band1',
					'band2',
					'band3',
					'band4',
					'band5',
					'band6',
					'band7',
					'band8',
					'band9']

		self.config = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]

		self.settings = Gio.Settings(EQUALIZER_DCONF_SCHEMA_ID)
		self.preset = self.settings[EQUALIZER_PRESET]

		self.read_settings(self.preset)
	
	def reset_all(self, eq):
		gst_presets = Gst.Preset.get_preset_names(eq)
		for preset in gst_presets + ["default"]:
			self.preset = preset
			if preset == "default":
				self.config = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]
			else:
				Gst.Preset.load_preset(eq, preset)
				self.config = list(eq.get_property('band' + str(i)) for i in range(0,10))
			self.write_settings()
		
	def read_settings(self, preset):
		for i in range(0,10):
			self.config[i] = self.read_value(preset, self.dconf_keys[i])

	def read_value(self, preset, value):
		band_settings = Gio.Settings.new_with_path(EQUALIZER_BANDS_DCONF_SCHEMA_ID,EQUALIZER_DCONF_PATH+preset+'/')
		return band_settings[value]

	def apply_settings(self, eq):
		for i in range(0, 10):
			eq.set_property('band' + `i`, self.config[i])

	def write_settings(self):
		preset = self.preset
		band_settings = Gio.Settings.new_with_path(EQUALIZER_BANDS_DCONF_SCHEMA_ID,EQUALIZER_DCONF_PATH+preset+'/')
		for i in range(0, 10):
			band_settings[self.dconf_keys[i]] = self.config[i]

	def change_preset(self, new_preset, eq):
		if not new_preset:
			return
		band_settings = Gio.Settings.new_with_path(EQUALIZER_BANDS_DCONF_SCHEMA_ID,EQUALIZER_DCONF_PATH+new_preset+'/')
		self.preset = new_preset
		self.settings[EQUALIZER_PRESET] = new_preset
		self.read_settings(new_preset)
		self.apply_settings(eq)

	def get_custom_presets(self):
		return	self.settings[EQUALIZER_CUSTOM_PRESETS]

	def add_custom_preset(self, new_custom_preset, eq):
		new_custom_preset_stripped = new_custom_preset.strip()
		new_custom_preset_stripped_lowered = new_custom_preset_stripped.lower()
		custom_presets = self.settings[EQUALIZER_CUSTOM_PRESETS]
		gst_presets = Gst.Preset.get_preset_names(eq)

		for custom_preset in custom_presets + gst_presets + ["default"]:
			if (custom_preset.strip().lower() == new_custom_preset_stripped_lowered):
				return custom_preset

		custom_presets.append(new_custom_preset_stripped)
		self.settings[EQUALIZER_CUSTOM_PRESETS] = custom_presets
		return new_custom_preset_stripped

	def delete_custom_preset(self, preset):
		custom_presets = self.settings[EQUALIZER_CUSTOM_PRESETS]
		custom_presets.remove(preset)
		self.settings[EQUALIZER_CUSTOM_PRESETS] = custom_presets
	
	def preset_exists(self, preset, eq):
		preset_stripped_lowered = preset.strip().lower()
		for existing_preset in Gst.Preset.get_preset_names(eq) + self.settings[EQUALIZER_CUSTOM_PRESETS] + ['default']:
			if existing_preset.strip().lower() == preset_stripped_lowered:
				return existing_preset
		return False

	def set_auto_select(self, value):
		self.settings[EQUALIZER_AUTO_SELECT] = value

	def get_auto_select(self):
		return self.settings[EQUALIZER_AUTO_SELECT]

